#!/bin/bash -ex
#SBATCH -J OG5_127924_no_dup_Tree
#SBATCH -p hh
#SBATCH -o out.%J
#SBATCH -n 16
#SBATCH -N 1
#SBATCH -t 14-00:00:00

# input
METAEUK_RESULTS_OUTDIR="/cramerdatabase2/soeding-temp/elevyka/predictExons/TaraEukRep5kb_EUK_profiles_011"
JOINT_FASTA="${METAEUK_RESULTS_OUTDIR}/OG5_127924_ANALYSIS/OG5_127924_OrthoMCL_MMETSP_metaeuk_no_dup_arc_bac_pols_all_domains.fasta"
OG5_127924_MMETSP_MAP="/cramerdatabase2/soeding-temp/elevyka/predictExons/TaraEukRep5KbPreds_EUK_markers_001/OG5_127924/MAPS/MMETSP_multi_match_OG5_127924_PFAM_domains_short_heads_map.txt"
OG5_127924_OrthoMCL_MAP="/cramerdatabase2/soeding-temp/elevyka/predictExons/TaraEukRep5KbPreds_EUK_markers_001/OG5_127924/MAPS/OG5_127924_all_domains_short_heads_map.txt"

# output
OUTDIR="${METAEUK_RESULTS_OUTDIR}/OG5_127924_ANALYSIS/MSA_TREE_HOMOLOGS_NO_DUP_METAEUK"
JOINT_MSA="OG5_127924_homologs_no_dup_MAFFT.fasta"
JOINT_TREE="OG5_127924_homologs_no_dup.nwc"
JOINT_TREE_BOOT="OG5_127924_homologs_no_dup_boot.nwc"
JOINT_TREE_TAXID="OG5_127924_homologs_no_dup_taxid.nwc"
JOINT_TREE_LIN="OG5_127924_homologs_no_dup_lineage.nwc"

# programs
SCRIPTS_DIR="/cbscratch/elevyka/predictExons/scripts"
MAFFT="/cbscratch/elevyka/predictExons/MAFFT/mafft-7.407-with-extensions/scripts/mafft"
FAST_TREE="/cbscratch/elevyka/predictExons/FastTree/FastTree"
RAxML="/cbscratch/elevyka/predictExons/RAxML/raxmlHPC-PTHREADS-AVX"

mkdir -p "${OUTDIR}"
cd "${OUTDIR}"

# run mafft #
if [ ! -f "${JOINT_MSA}" ]
then
	"${MAFFT}" "${JOINT_FASTA}" > "${JOINT_MSA}";
fi

# run FastTree #
if [ ! -f FastTree."${JOINT_TREE}" ]
then
	"${FAST_TREE}" "${JOINT_MSA}" > FastTree."${JOINT_TREE}"

	# translate MMETSP identifiers #
	perl "${SCRIPTS_DIR}"/replace_OrthoMCL_labels_in_tree_by_map.pl FastTree."${JOINT_TREE}" "${OG5_127924_MMETSP_MAP}" "taxid" FastTree."${JOINT_TREE_TAXID}"
	perl "${SCRIPTS_DIR}"/replace_OrthoMCL_labels_in_tree_by_map.pl FastTree."${JOINT_TREE}" "${OG5_127924_MMETSP_MAP}" "lineage" FastTree."${JOINT_TREE_LIN}"

	# translate OrthoMCL identifiers #
	perl "${SCRIPTS_DIR}"/replace_OrthoMCL_labels_in_tree_by_map.pl FastTree."${JOINT_TREE_TAXID}" "${OG5_127924_OrthoMCL_MAP}" "taxid" FastTree."${JOINT_TREE_TAXID}"
	perl "${SCRIPTS_DIR}"/replace_OrthoMCL_labels_in_tree_by_map.pl FastTree."${JOINT_TREE_LIN}" "${OG5_127924_OrthoMCL_MAP}" "lineage" FastTree."${JOINT_TREE_LIN}"
fi

# run RAxML ML #
if [ ! -f RAxML_bestTree."${JOINT_TREE}" ]
then
	"${RAxML}" -s "${JOINT_MSA}" -n "${JOINT_TREE}" -m PROTGAMMALG -p 12345 -T 16
	
	# translate MMETSP identifiers #
	perl "${SCRIPTS_DIR}"/replace_OrthoMCL_labels_in_tree_by_map.pl RAxML_bestTree."${JOINT_TREE}" "${OG5_127924_MMETSP_MAP}" "taxid" RAxML_bestTree."${JOINT_TREE_TAXID}"
	perl "${SCRIPTS_DIR}"/replace_OrthoMCL_labels_in_tree_by_map.pl RAxML_bestTree."${JOINT_TREE}" "${OG5_127924_MMETSP_MAP}" "lineage" RAxML_bestTree."${JOINT_TREE_LIN}"

	# translate OrthoMCL identifiers #
	perl "${SCRIPTS_DIR}"/replace_OrthoMCL_labels_in_tree_by_map.pl RAxML_bestTree."${JOINT_TREE_TAXID}" "${OG5_127924_OrthoMCL_MAP}" "taxid" RAxML_bestTree."${JOINT_TREE_TAXID}"
	perl "${SCRIPTS_DIR}"/replace_OrthoMCL_labels_in_tree_by_map.pl RAxML_bestTree."${JOINT_TREE_LIN}" "${OG5_127924_OrthoMCL_MAP}" "lineage" RAxML_bestTree."${JOINT_TREE_LIN}"
fi

# run RAxML bootstrap #
if [ ! -f RAxML_bootstrap."${JOINT_TREE_BOOT}" ]
then
	"${RAxML}" -s "${JOINT_MSA}" -n "${JOINT_TREE_BOOT}" -m PROTGAMMALG -p 12345 -T 16 -x 12345 -# 100
fi

# augment RAxML with Bootstrap #
if [ ! -f RAxML_bipartitions.RAxML_bestTree_with_boot."${JOINT_TREE}" ]
then
	"${RAxML}" -f b -t RAxML_bestTree."${JOINT_TREE}" -z RAxML_bootstrap."${JOINT_TREE_BOOT}" -m PROTGAMMALG -n RAxML_bestTree_with_boot."${JOINT_TREE}"
	
	# translate MMETSP identifiers #
	perl "${SCRIPTS_DIR}"/replace_OrthoMCL_labels_in_tree_by_map.pl RAxML_bipartitions.RAxML_bestTree_with_boot."${JOINT_TREE}" "${OG5_127924_MMETSP_MAP}" "taxid" RAxML_bestTree_with_boot."${JOINT_TREE_TAXID}"
	perl "${SCRIPTS_DIR}"/replace_OrthoMCL_labels_in_tree_by_map.pl RAxML_bipartitions.RAxML_bestTree_with_boot."${JOINT_TREE}" "${OG5_127924_MMETSP_MAP}" "lineage" RAxML_bestTree_with_boot."${JOINT_TREE_LIN}"

	# translate OrthoMCL identifiers #
	perl "${SCRIPTS_DIR}"/replace_OrthoMCL_labels_in_tree_by_map.pl RAxML_bestTree_with_boot."${JOINT_TREE_TAXID}" "${OG5_127924_OrthoMCL_MAP}" "taxid" RAxML_bestTree_with_boot."${JOINT_TREE_TAXID}"
	perl "${SCRIPTS_DIR}"/replace_OrthoMCL_labels_in_tree_by_map.pl RAxML_bestTree_with_boot."${JOINT_TREE_LIN}" "${OG5_127924_OrthoMCL_MAP}" "lineage" RAxML_bestTree_with_boot."${JOINT_TREE_LIN}"
fi







